package MT::Plugin::OMV::LogCleaner;

use strict;
use MT 4;
use MT::Blog;
use MT::Log;

use vars qw( $NAME $VERSION );
$NAME = (split /::/, __PACKAGE__)[-1];
$VERSION = '0.01';

use base qw( MT::Plugin );
my $plugin = __PACKAGE__->new ({
    id => $NAME,
    key => $NAME,
    name => $NAME,
    version => $VERSION,
    author_name => 'Open MagicVox.net',
    author_link => 'http://www.magicvox.net/',
    doc_link => 'http://www.magicvox.net/archive/2010/11072239/',
    description => <<'HTMLHEREDOC',
<__trans phrase="Clean the logs along with the specified condtions.">
HTMLHEREDOC
    config_template => 'tmpl/config.tmpl',
    settings => new MT::PluginSettings ([
        ['config', { Default => '' }],
    ]),
    registry => {
        tasks => {
            $NAME => {
                name        => $NAME,
                frequency   => 60 * 60,
                code        => \&_hdlr_clean_logs,
            },
        },
    },
});
MT->add_plugin ($plugin);

sub _hdlr_clean_logs {
    my ($cb) = @_;

    my @blog_ids = (0, map { $_->id } MT::Blog->load());
    for my $blog_id (@blog_ids) {
        my $config = $plugin->get_config_value ('config', $blog_id ? "blog:$blog_id" : 'system')
            or next; # not yet configured

        for my $line (split /[\r\n]+/, $config) {
            my ($cat, $class, $level) = split /,/, $line;
            defined $cat && defined $class && defined $level
                or next; # Illegal configuration
            $cat   =~ s/\s+//g;
            $class =~ s/\s+//g;
            $level =~ s/\s+//g;

            for (MT::Log->load({ blog_id => $blog_id, class => '*' })) {
                $_->remove
                    if ($cat eq '*'
                        || ($cat =~ /^!/
                            ? $cat =~ s/!// && $cat ne ($_->category || 'NULL')
                            :                  $cat eq ($_->category || 'NULL')))
                    && ($class eq '*'
                        || ($class =~ /^!/
                            ? $class =~ s/!// && $class ne ($_->class || 'NULL')
                            :                    $class eq ($_->class || 'NULL')))
                    && ($level eq '*'
                        || ($level =~ /^!/
                            ? $level =~ s/!// && $level ne $_->level
                            :                    $level eq $_->level));
            }
        }
    }
}

1;